| /llvm-project-15.0.7/clang/test/CodeGenCUDA/ |
| H A D | surface.cu | 13 struct __attribute__((device_builtin_surface_type)) surface : public surfaceReference { struct 18 struct __attribute__((device_builtin_surface_type)) surface<void, dim> : public surfaceReference { struct 26 surface<void, 2> surf; 28 __attribute__((device)) int suld_2d_zero(surface<void, 2>, int, int) asm("llvm.nvvm.suld.2d.i32.zer…
|
| /llvm-project-15.0.7/clang/test/SemaCUDA/ |
| H A D | const-var.cu | 76 struct __attribute__((device_builtin_surface_type)) surface : public surfaceReference { struct 81 struct __attribute__((device_builtin_surface_type)) surface<void, dim> : public surfaceReference { struct 85 surface<void, 2> surf; 99 __device__ static surface<void, 2> *const p7; 110 __device__ surface<void, 2> *const B::p7 = &surf;
|
| H A D | constexpr-var.cu | 77 struct __attribute__((device_builtin_surface_type)) surface : public surfaceReference { struct 82 struct __attribute__((device_builtin_surface_type)) surface<void, dim> : public surfaceReference { struct 86 surface<void, 2> surf; 103 __device__ static constexpr surface<void, 2> *const p7 = &surf;
|
| /llvm-project-15.0.7/lldb/source/Core/ |
| H A D | IOHandlerCursesGUI.cpp | 1116 surface.PutCString(text, surface.GetWidth()); in DrawContent() 1147 surface.PutChar(' '); in DrawError() 1466 surface.PutChar('['); in FieldDelegateDraw() 1472 surface.PutChar(']'); in FieldDelegateDraw() 1473 surface.PutChar(' '); in FieldDelegateDraw() 1773 surface.MoveCursor(1, surface.GetHeight() / 2); in DrawRemoveButton() 2268 surface.PutChar('['); in Draw() 2270 surface.PutChar(']'); in Draw() 2576 surface.PutChar(' '); in DrawError() 2581 surface.HorizontalLine(surface.GetWidth()); in DrawError() [all …]
|
| /llvm-project-15.0.7/llvm/test/CodeGen/NVPTX/ |
| H A D | annotations.ll | 8 @surface = internal addrspace(1) global i64 0, align 8 9 ; CHECK: .global .surfref surface 54 !10 = !{i64 addrspace(1)* @surface, !"surface", i32 1}
|
| H A D | surf-write-cuda.ll | 43 !3 = !{i64 addrspace(1)* @surf0, !"surface", i32 1}
|
| H A D | surf-read-cuda.ll | 54 !3 = !{i64 addrspace(1)* @surf0, !"surface", i32 1}
|
| H A D | texsurf-queries.ll | 105 !2 = !{i64 addrspace(1)* @surf0, !"surface", i32 1}
|
| /llvm-project-15.0.7/llvm/docs/AMDGPU/ |
| H A D | gfx10_vdata_a9ff5a.rst | 24 …Note: the surface data format is indicated in the image resource constant but not in the instructi…
|
| H A D | gfx10_vdata_35851e.rst | 24 …Note: the surface data format is indicated in the image resource constant but not in the instructi…
|
| H A D | gfx1030_vdata_a9ff5a.rst | 24 …Note: the surface data format is indicated in the image resource constant but not in the instructi…
|
| H A D | gfx1030_vdata_35851e.rst | 24 …Note: the surface data format is indicated in the image resource constant but not in the instructi…
|
| H A D | gfx9_vdata_35851e.rst | 24 …Note: the surface data format is indicated in the image resource constant but not in the instructi…
|
| H A D | gfx9_vdata_a9ff5a.rst | 24 …Note: the surface data format is indicated in the image resource constant but not in the instructi…
|
| H A D | gfx90a_vdata_af2725.rst | 24 …Note: the surface data format is indicated in the image resource constant but not in the instructi…
|
| H A D | gfx90a_vdata_ca6e5f.rst | 24 …Note: the surface data format is indicated in the image resource constant but not in the instructi…
|
| H A D | gfx8_vdata_325b78.rst | 24 …Note: the surface data format is indicated in the image resource constant but not in the instructi…
|
| H A D | gfx8_vdata_4d8ecf.rst | 24 …Note: the surface data format is indicated in the image resource constant but not in the instructi…
|
| H A D | gfx7_vdata_4d8ecf.rst | 24 …Note: the surface data format is indicated in the image resource constant but not in the instructi…
|
| H A D | gfx7_vdata_325b78.rst | 24 …Note: the surface data format is indicated in the image resource constant but not in the instructi…
|
| /llvm-project-15.0.7/llvm/lib/Target/NVPTX/ |
| H A D | NVPTXInstrFormats.td | 44 // with 0 meaning the operation is not a surface instruction. For example,
|
| /llvm-project-15.0.7/llvm/test/CodeGen/Hexagon/ |
| H A D | trivialmemaliascheck.ll | 6 ; surface. do not have only one mem operand. However, the backend knows MIs and
|
| /llvm-project-15.0.7/clang/tools/clang-fuzzer/ |
| H A D | README.txt | 7 primarily useful for stressing the surface layers of Clang (i.e. lexer, parser).
|
| /llvm-project-15.0.7/llvm/docs/ |
| H A D | FuzzingLLVM.rst | 181 mutations. This type of fuzzer is good for stressing the surface layers of a
|
| /llvm-project-15.0.7/mlir/docs/Rationale/ |
| H A D | UsageOfConst.md | 126 things like this, which is twice as much API surface area just to try to satisfy
|